@@ -237,6 +237,8 @@ def converttype(thetype):
 		thetype = 'ulong'
 	if(thetype == 'VRInputValueHandle_t'):
 		thetype = 'ulong'
+	if(thetype == 'VRInputComponentHandle_t'):
+		thetype = 'ulong'
 	if(thetype == 'VRInputOriginHandle_t'):
 		thetype = 'ulong'
 	if(thetype == 'PathHandle_t'):
@@ -247,6 +249,10 @@ def converttype(thetype):
 		thetype = 'int'
 	if(thetype == 'WebConsoleHandle_t'):
 		thetype = 'ulong'
+	if(thetype == 'vrshared_double'):
+		thetype = 'double'
+	if(thetype == 'vrshared_uint64_t'):
+		thetype = 'ulong'
 
 	if(thetype[0:7] == 'struct '):
 		thetype = thetype[7:]
@@ -518,8 +524,12 @@ def outputinterfaces(namespace, data):
 							paramlist.append('ref ' + paramtype + ' ' + param['paramname'])
 					else:
 						paramlist.append(paramtype + ' ' + param['paramname'])
+					if(paramtype == 'bool'):
+						paramlist[-1] = '[MarshalAs(UnmanagedType.I1)] ' + paramlist[-1];
 
 			print("\t\t[UnmanagedFunctionPointer(CallingConvention.StdCall)]")
+			if(returntype == 'bool'):
+				print("\t\t[return: MarshalAs(UnmanagedType.I1)]")
 			print("\t\tinternal delegate "+returntype+" _"+methodname+"("+", ".join(paramlist)+");")
 			print("\t\t[MarshalAs(UnmanagedType.FunctionPtr)]")
 			print("\t\tinternal _"+methodname+" "+methodname+";\n")
@@ -589,6 +599,11 @@ def outputfntabledecls(namespace, data):
 			if(namespace != getnamespace(classname)):
 				continue
 
+			# Skip over destructors, we don't use any aside from dummy ones, and
+			# destroying our interfaces would be broken anyway.
+			if(methodname[:8] == 'Destruct'):
+				continue
+
 			classname = getclasswithoutnamespace(classname)
 			if(classname != lastclass):
 				if(lastclass != ''):
@@ -657,6 +672,11 @@ def outputfntablefuncs(namespace, data):
 			if(namespace != getnamespace(classname)):
 				continue
 
+			# Skip over destructors, we don't use any aside from dummy ones, and
+			# destroying our interfaces would be broken anyway.
+			if(method['methodname'][:8] == 'Destruct'):
+				continue
+
 			classname = getclasswithoutnamespace(classname)
 			if(classname != lastclass):
 				if(lastclass != ''):
@@ -751,7 +771,7 @@ def outputclasses(namespace, data):
 	# the following methods take a mispacked VRControllerState_t on Linux and OSX so we generate
 	# a special hacky method to account for that on those platforms.
 	controller_packed_methods = ['GetControllerState', 'GetControllerStateWithPose', 'GetComponentState']
-	event_packed_methods      = ['PollNextEvent', 'PollNextEventWithPost', 'PollNextOverlayEvent']
+	event_packed_methods      = ['PollNextEvent', 'PollNextEventWithPose', 'PollNextOverlayEvent', 'PollNextOverlayEventForAny']
 	if(namespace == ''):
 		namespaceextra = ''
 	elif(namespace == 'vr'):
